#ifndef NT2_INCLUDE_FUNCTIONS_GAMMAINCINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GAMMAINCINV_HPP_INCLUDED

#include <nt2/euler/include/functions/gammaincinv.hpp>

#endif
